@@ -3,7 +3,7 @@
 
 # In[ ]:
 
-import model as md
+import toynn.model as mdl
 
 def make(file):
         
@@ -12,7 +12,7 @@ def make(file):
         
     #create a default model
         
-    model = md.ANN((1,1), (1, 1), "sigmoid")
+    model = mdl.ANN((1,1), (1, 1), "sigmoid")
         
     #essential imports
         
